% INIT_TEMP Calculates initial distribution of temperature, density and
% fraction of spinel (beta) and its derivatives with respect to z (betaz)
% and T (betat)
%	Also the distribution of heat production H and basal heat flow qb is 
%   calculated (it will be maintainted constant)
%	We consider the possibility of continental or oceanic subduction
% 	A conductive geotherm is assumed for the lithosphere and anadiabatic 
% gradient underneath the lithosphere. Also a temperature increase dt1=Lt/cp
% (e.g. Duvaux et al., 1997) is assumed to occur in the area of olivine to
% spinel phase change.
%
% We define the depths of the base of the lithosphere (za) 
%                             base of the interval of phase change (ztr1)
%                             top of the interval of phase change (ztr2)
% all of them are refered to the base of the upper mantle depth 

% Script component of TEMSPOL: a MATLAB thermal model for deep subduction
% zones including major phase transformations.
% A.M. Negredo, J.L. Valera and E. Carminati (2002)


za=depth-L;

% 	The equations of the stright indicating the initiation (z2) and end 
% (z1) of Ol-Sp transformation are taken form Schmeling et al., 1999, EPSL,
% 165, p55-66. Figure 1. 
% z2=-2000/15*T+depth-200000
% z1=-2000/15*T+depth-290000

% ztr2 is the cross point between z2 and the adiabat geotherm in the 
% asthenosphere 

ztr2=fzero('funztr2',270000); 
tztr2=T0*exp(g*alpha/Cp*(za-ztr2));
dt1=abs(Lt)/Cp;
tztr1=tztr2+dt1;
ztr1=-2000/15*tztr1+depth-290000;
for j=1:J
    z=(j-1)*Dz;
    if z<=ztr1
% temperature distribution at depths from the base of the model to ztr1        
        T1(j)=(tztr2+dt1)*exp(g*alpha/Cp*(ztr1-z));
        beta0(j)=1;
        betaz0(j)=0;
        betat0(j)=0;
        rho0(j)=(rhom+drho_olsp)*(1-alpha*T1(j));
        % calculation of basal heat flow:
        if j==2
            qb=K/Dz*(T1(1)-T1(2));
        end
    else 
% temperature is assumed to increase linearly between ztr2 and ztr1
% we do not consider the possibility of having metastable olivine
        if z<=ztr2
            T1(j)=dt1*(ztr2-z)/(ztr2-ztr1)+tztr2;
            beta0(j)=(ztr2-z)/(ztr2-ztr1);
            betaz0(j)=-1/90000;
            betat0(j)=-1/(15/2*90);
            rho0(j)=(rhom+drho_olsp*beta0(j))*(1-alpha*T1(j));
% temperature distribution in the asthenosphere            
        elseif z<za
            T1(j)=T0*exp(g*alpha/Cp*(za-z));
            beta0(j)=0;
            betaz0(j)=0;
            betat0(j)=0;
            rho0(j)=rhom*(1-alpha*T1(j));
% temperature distribution in the oceanic lithosphere of a given age (plate model)             
        elseif hc==0
            for n=1:10
                a(n)=2/(n*pi)*sin(n*pi*(depth-z)/L)*exp(-n^2*pi^2*K*age/(rhom*Cp*L^2));
            end
            T1(j)=T0*((depth-z)/L+sum(a));
            beta0(j)=0;
            betaz0(j)=0;
            betat0(j)=0;
            rho0(j)=rhom*(1-alpha*T1(j));
% temperature distribution in the continental lithosphere            
        else
           % at lithospheric mantle depths
           if z<=depth-hc
               T1(j)=(T0/L-Hp*hc^2/(K*L))*(depth-z)+Hp*hc^2/K;
               beta0(j)=0;
               betaz0(j)=0;
               betat0(j)=0;
               rho0(j)=rhom*(1-alpha*T1(j));
           % at crustal depths. We assume T1=0 at the surface of the model    
           else
               T1(j)=-Hp/K*(depth-z)^2+(T0/L-Hp*hc^2/(K*L)+2*Hp*hc/K)*(depth-z);
               beta0(j)=0;
               betaz0(j)=0;
               betat0(j)=0;
               rho0(j)=rhoc*(1-alpha*T1(j));
           end
        end
    end
% assignement for all the columns:     
    T(1:I,j)=T1(j);
    beta(1:I,j)=beta0(j);
    betaz(1:I,j)=betaz0(j);
    betat(1:I,j)=betat0(j);
    rho(1:I,j)=rho0(j);
end
H(1:I,1:J)=0;
qb(1:I)=qb;
clear T1 beta0 betaz0 betat0 rho0 ztr1 ztr2 tztr1 tztr2 dt1 z;
 